/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { IndicesGetMappingIndexMappingRecord } from '@elastic/elasticsearch/lib/api/types';

import { Actions, createApiLogic } from '../../../shared/api_logic/create_api_logic';
import { HttpLogic } from '../../../shared/http';

export interface GetMappingsArgs {
  indexName: string;
}

export type GetMappingsResponse = IndicesGetMappingIndexMappingRecord;

export type GetMappingsActions = Actions<GetMappingsArgs, GetMappingsResponse>;

export const getMappings = async ({ indexName }: GetMappingsArgs) => {
  const route = `/internal/enterprise_search/mappings/${indexName}`;

  return await HttpLogic.values.http.get<IndicesGetMappingIndexMappingRecord>(route);
};

export const mappingsWithPropsApiLogic = (indexName: string) =>
  createApiLogic(['mappings_api_logic_with_props', indexName], getMappings);

export const MappingsApiLogic = createApiLogic(['mappings_api_logic'], getMappings);
